/* HumbleInpatientView */

import com.apple.cocoa.foundation.*;
import com.apple.cocoa.application.*;
import com.testingthought.humble.ui.InpatientView;


public class HumbleInpatientView extends InpatientView 
			implements NSTableView.DataSource {

    public NSTextField animalNameField; /* IBOutlet */
    public NSTextField ownerNameField; /* IBOutlet */
    public NSTableView patientTable; /* IBOutlet */
	public NSButton addCaseButton; /* IBOutlet */

	// Startup
	
	public void awakeFromNib() {
		app().note(this);
		patientTable.setDataSource(this);
	}

	// Calls from Cocoa - entering a case

	// For some reason, the runtime can't find addCasePressed. I'm wondering
	// if it's because the superclass's addCasePressed has a method with the
	// same name but a different set of arguments.
    public void addCasePressed2(Object sender) { /* IBAction */
		addCasePressed();
    }

    public void animalNameEntered(Object sender) { /* IBAction */
		System.out.println("animal name entered");
		super.animalNameEntered(animalNameField.stringValue());
    }

    public void ownerNameEntered(Object sender) { /* IBAction */
		System.out.println("owner name entered");
		super.ownerNameEntered(ownerNameField.stringValue());
    }

    public void patientRowSelected(Object sender) { /* IBAction */
		clickedRow(patientTable.selectedRow());
    }

	// Methods called from NSTable.

	public int numberOfRowsInTableView(NSTableView aTableView) {
		return getNumberOfCases();
	}
	
	public Object tableViewObjectValueForLocation(NSTableView aTableView,
				NSTableColumn aTableColumn, int rowIndex) {
		return getCaseSummary(rowIndex);
	}


	// Calls from Presenter

	public void highlightRow(int row) {
		System.out.println("highlighting " + row + ". Why does this not highlight added row?");
		patientTable.selectRowIndexes(new NSIndexSet(row), false);
		// todo: Note that if you change this to always select row 0, 
		// row 0 will not be highlighted when first case is entered, but
		// then will highlight after case 1 is.
	}
	
	public void refresh() {
		patientTable.reloadData();
	}

	// This is true because there's no other panel on the screen.
	public boolean isYourWindowActive() {
		return true;
	}
	
	public void makeYourWindowActive() {
	}
	

	public void disallowAddCase() {
	   addCaseButton.setEnabled(false);
	}
	
	public void allowAddCase() {
		addCaseButton.setEnabled(true);
	}
	
	public void emptyOwnerNameField() {
		animalNameField.setStringValue("");
	}
	
	public void emptyAnimalNameField() {
		ownerNameField.setStringValue("");
	}
	

	

	// Unused table interface methods.
	public void tableViewSetObjectValueForLocation(NSTableView aTableView,
				Object obj, NSTableColumn aTableColumn, int rowIndex) {
		assert false;
	}
	
	public boolean tableViewAcceptDrop(NSTableView view, NSDraggingInfo info, 
				int row, int operation) {
		assert false;
		return false;
	}
	
	
	public int tableViewValidateDrop(NSTableView view, NSDraggingInfo info, 
				int row, int operation) {
		assert false;
		return 0;
	}
	
	public boolean tableViewWriteRowsToPasteboard(NSTableView view, NSArray rows,
				NSPasteboard pboard) {
		assert false;
		return false;
	}
	
	public void tableViewSortDescriptorsDidChange(NSTableView view, 
					NSArray oldDescriptors) {
		assert false;
	}
}
