package com.testingthought.humble.ui;

import com.testingthought.humble.model.Case;

import java.util.ArrayList;

public class InpatientPresenter extends Presenter {

    private String animalNameForNextCase;
    private String ownerNameForNextCase;
    private ArrayList cases = new ArrayList();

    public InpatientPresenter() {
        super();
        clearNames();
    }

    // From View
    public void animalNameEntered(String name) {
        this.animalNameForNextCase = name;
        maybeAllowCaseToBeAdded();
    }

    public void ownerNameEntered(String name) {
        this.ownerNameForNextCase = name;
        maybeAllowCaseToBeAdded();
    }

    public void selectCase(int index) {
        tellPeerPresentersOfNewCase(index);
    }

    public void addCasePressed() {
        cases.add(new Case(animalNameForNextCase, ownerNameForNextCase));
        tellPeerPresentersOfNewCase(lastCaseIndex());
        tellViewOfNewCase();
        readyViewForNextCase();
        clearNames();
    }

    // From elsewhere inside the program
    public void makeYourWindowActive() {
        myView().makeYourWindowActive();
    }

    public void readyView() {
        myView().disallowAddCase();
    }

    public boolean hasNoOwnerName() {
        return ownerNameForNextCase == "";
    }

    public boolean hasNoAnimalName() {
        return animalNameForNextCase == "";
    }

    public Case caseAt(int index) {
        return (Case)cases.get(index);
    }


    // Util for view-called methods
    private void maybeAllowCaseToBeAdded() {
        if (hasNoOwnerName()) return;
        if (hasNoAnimalName()) return;
        myView().allowAddCase();
    }

    private void tellPeerPresentersOfNewCase(int index) {
        peer().handleNewCase(caseAt(index));
    }

    private void tellViewOfNewCase() {
        myView().highlightRow(lastCaseIndex());
        myView().refresh();
    }

    private void readyViewForNextCase() {
        myView().emptyAnimalNameField();
        myView().emptyOwnerNameField();
        myView().disallowAddCase();
    }

    // Util
    public int getNumberOfCases() {
        return cases.size();
    }

    private int lastCaseIndex() {
        return getNumberOfCases()-1;
    }

    public String getCaseSummary(int index) {
        return (caseAt(index)).terseCaseSummary();
    }

    public int indexForCase(String animalName, String ownerName) {
        return cases.indexOf(new Case(animalName, ownerName));
    }


    private void clearNames() {
        animalNameForNextCase = "";
        ownerNameForNextCase = "";
    }

    private PatientDetailPresenter peer() {
        return app().getPatientDetailPresenter();
    }

    private InpatientView myView() {
        return app().getInpatientView();
    }
}
