package com.testingthought.humble.ui;

import com.testingthought.humble.model.Case;

import java.util.List;
import java.util.Arrays;

public class InpatientPresenterTest extends UITestCase {
    private List disallowed =
            Arrays.asList(new String[]{ "disallowed" });
    private List nowAllowed =
            Arrays.asList(new String[]{ "disallowed", "allowed" });
    private List disallowedAgain =
            Arrays.asList(new String[]{ "disallowed", "allowed", "disallowed" });


    private String summaryFor(String animal, String owner) {
        // We assume Case works correctly.
        return new Case(animal, owner).terseCaseSummary();
    }

    public void testSuccessfulCaseAddition() throws Exception {
        inpatientView().addCase("Betsy", "Rankin");

        assertEquals(1, inpatientPresenter().getNumberOfCases());
        assertEquals(summaryFor("Betsy", "Rankin"),
                     inpatientPresenter().getCaseSummary(0));
        assertTrue(inpatientView().wasTableRefreshed());
        assertTrue(inpatientView().wasARowHighlighted());
        assertEquals(0, inpatientView().getHighlightedRowIndex());
        assertTrue(patientDetailView().wasHeadingSet());
        assertEquals(summaryFor("Betsy", "Rankin"),
                     patientDetailView().getHeading());
    }

    public void testCreationRequiresBothNames() {
        assertEquals(disallowed, inpatientView().getAddCaseCommands());
        inpatientView().animalNameEntered("animal data");
        assertEquals(disallowed, inpatientView().getAddCaseCommands());

        inpatientView().ownerNameEntered("owner data");
        assertEquals(nowAllowed, inpatientView().getAddCaseCommands());
    }

    public void testDifferentNameOrderDoesNotFoolDataCheck() {
        inpatientView().animalNameEntered("animal data");
        assertEquals(disallowed, inpatientView().getAddCaseCommands());

        inpatientView().ownerNameEntered("owner data");
        assertEquals(nowAllowed, inpatientView().getAddCaseCommands());
    }

    public void testEnteringCaseErasesPreviousNames() {
        inpatientView().ownerNameEntered("owner");
        inpatientView().animalNameEntered("animal");
        inpatientView().addCasePressed();
        assertEquals(disallowedAgain, inpatientView().getAddCaseCommands());
        assertTrue(inpatientPresenter().hasNoAnimalName());
        assertTrue(inpatientPresenter().hasNoOwnerName());
        assertTrue(inpatientView().wasTheAnimalFieldNameEmptied());
        assertTrue(inpatientView().wasTheOwnerNameFieldEmptied());
    }


    // The list of cases.

    public void testPresenterMaintainsAListOfCases() throws Exception {
        inpatientView().addCase("Betsy", "Rankin");
        inpatientView().addCase("Susie", "Peoria");
        assertEquals(2, inpatientPresenter().getNumberOfCases());
        assertEquals(summaryFor("Betsy", "Rankin"),
                     inpatientPresenter().caseAt(0).terseCaseSummary());
        assertEquals(summaryFor("Susie", "Peoria"),
                     inpatientPresenter().caseAt(1).terseCaseSummary());
    }


    public void testCaseRowSelection() {
        inpatientView().addCase("a cow", "a farmer");
        inpatientView().addCase("a llama", "a hobbyist");
        inpatientView().clickedRow(0);

        assertTrue(patientDetailView().wasHeadingSet());
        assertEquals(summaryFor("a cow", "a farmer"),
                     patientDetailView().getHeading());

        inpatientView().clickedRow(1);
        assertEquals(summaryFor("a llama", "a hobbyist"),
                     patientDetailView().getHeading());
    }

    public void testFindCaseByNames() {
        inpatientView().addCase("Betsy", "Rankin");
        assertEquals(0, inpatientPresenter().indexForCase("Betsy", "Rankin"));

        inpatientView().addCase("second", "case");
        assertEquals(1, inpatientPresenter().indexForCase("second", "case"));
        assertEquals(0, inpatientPresenter().indexForCase("Betsy", "Rankin"));
    }

}
